@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <TestStdAlgorithmsCommon.hpp>
 #include <algorithm>
@@ -55,7 +42,6 @@ void test_for_each(const ViewType view) {
   std::for_each(KE::begin(expected), KE::end(expected), non_mod_functor);
   compare_views(expected, view);
 
-#if defined(KOKKOS_ENABLE_CXX11_DISPATCH_LAMBDA)
   const auto mod_lambda = KOKKOS_LAMBDA(value_t & i) { ++i; };
 
   // pass view, lambda takes non-const ref
@@ -79,7 +65,6 @@ void test_for_each(const ViewType view) {
   KE::for_each(exespace(), KE::cbegin(view), KE::cend(view), non_mod_lambda);
   std::for_each(KE::cbegin(expected), KE::cend(expected), non_mod_lambda);
   compare_views(expected, view);
-#endif
 }
 
 // std::for_each_n is C++17, so we cannot compare results directly
@@ -91,23 +76,23 @@ void test_for_each_n(const ViewType view) {
   const auto non_mod_functor = NoOpNonMutableFunctor<value_t>();
 
   // pass const iterators, functor takes const ref
-  EXPECT_EQ(KE::cbegin(view) + n,
+  ASSERT_EQ(KE::cbegin(view) + n,
             KE::for_each_n(exespace(), KE::cbegin(view), n, non_mod_functor));
   verify_values(value_t{0}, view);
 
   // pass view, functor takes const ref
-  EXPECT_EQ(KE::begin(view) + n,
+  ASSERT_EQ(KE::begin(view) + n,
             KE::for_each_n(exespace(), view, n, non_mod_functor));
   verify_values(value_t{0}, view);
 
   // pass iterators, functor takes non-const ref
   const auto mod_functor = IncrementElementWiseFunctor<value_t>();
-  EXPECT_EQ(KE::begin(view) + n,
+  ASSERT_EQ(KE::begin(view) + n,
             KE::for_each_n(exespace(), KE::begin(view), n, mod_functor));
   verify_values(value_t{1}, view);
 
   // pass view, functor takes non-const ref
-  EXPECT_EQ(KE::begin(view) + n,
+  ASSERT_EQ(KE::begin(view) + n,
             KE::for_each_n("label", exespace(), view, n, mod_functor));
   verify_values(value_t{2}, view);
 }
