@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <TestStdAlgorithmsCommon.hpp>
 
@@ -194,21 +181,10 @@ void test_A(std::size_t numTeams, std::size_t numCols, int apiId) {
 
     ASSERT_TRUE(intraTeamSentinelView_h(i));
 
-    // libstdc++ as provided by GCC 8 does not have reduce, transform_reduce,
-    // exclusive_scan, inclusive_scan, transform_exclusive_scan,
-    // transform_inclusive_scan and for GCC 9.1, 9.2 fails to compile them for
-    // missing overload not accepting policy
-
-#if defined(_GLIBCXX_RELEASE) && (_GLIBCXX_RELEASE <= 9)
-#define reduce testing_reduce
-#else
-#define reduce std::reduce
-#endif
-
     switch (apiId) {
       case 0:
       case 1: {
-        const ValueType result = reduce(rowFromBegin, rowFromEnd);
+        const ValueType result = std::reduce(rowFromBegin, rowFromEnd);
         if constexpr (std::is_floating_point_v<ValueType>) {
           EXPECT_FLOAT_EQ(result, reduceResultsView_h(i));
         } else {
@@ -220,7 +196,7 @@ void test_A(std::size_t numTeams, std::size_t numCols, int apiId) {
 
       case 2:
       case 3: {
-        const ValueType result = reduce(rowFromBegin, rowFromEnd, initVal);
+        const ValueType result = std::reduce(rowFromBegin, rowFromEnd, initVal);
         if constexpr (std::is_floating_point_v<ValueType>) {
           EXPECT_FLOAT_EQ(result, reduceResultsView_h(i));
         } else {
@@ -233,7 +209,7 @@ void test_A(std::size_t numTeams, std::size_t numCols, int apiId) {
       case 4:
       case 5: {
         const ValueType result =
-            reduce(rowFromBegin, rowFromEnd, initVal, binaryPred);
+            std::reduce(rowFromBegin, rowFromEnd, initVal, binaryPred);
         if constexpr (std::is_floating_point_v<ValueType>) {
           EXPECT_FLOAT_EQ(result, reduceResultsView_h(i));
         } else {
@@ -244,8 +220,6 @@ void test_A(std::size_t numTeams, std::size_t numCols, int apiId) {
       }
       default: Kokkos::abort("unreachable");
     }
-
-#undef reduce
   }
 }
 
