@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <Kokkos_Macros.hpp>
 
@@ -25,14 +12,17 @@
 
 #include <gtest/gtest.h>
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+import kokkos.unordered_map;
+#else
 #include <Kokkos_Core.hpp>
+#include <Kokkos_UnorderedMap.hpp>
+#endif
 
 #include <TestDynRankView.hpp>
-
-#include <Kokkos_UnorderedMap.hpp>
-
 #include <TestGlobal2LocalIds.hpp>
-
 #include <TestUnorderedMapPerformance.hpp>
 
 namespace Performance {
