@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #ifndef KOKKOS_THREADS_INSTANCE_HPP
 #define KOKKOS_THREADS_INSTANCE_HPP
@@ -60,7 +47,7 @@ class ThreadsInternal {
   int m_pool_rank_rev;
   int m_pool_size;
   int m_pool_fan_size;
-  ThreadState volatile m_pool_state;  ///< State for global synchronizations
+  std::atomic<ThreadState> m_pool_state;  ///< State for global synchronizations
 
   // Members for dynamic scheduling
   // Which thread am I stealing from currently
@@ -96,7 +83,7 @@ class ThreadsInternal {
     return reinterpret_cast<unsigned char *>(m_scratch) + m_scratch_reduce_end;
   }
 
-  KOKKOS_INLINE_FUNCTION ThreadState volatile &state() { return m_pool_state; }
+  KOKKOS_INLINE_FUNCTION auto &state() { return m_pool_state; }
   KOKKOS_INLINE_FUNCTION ThreadsInternal *const *pool_base() const {
     return m_pool_base;
   }
@@ -225,7 +212,7 @@ class ThreadsInternal {
     //  to inactive triggers another thread to exit a spinwait
     //  and read the 'reduce_memory'.
     //  Must 'memory_fence()' to guarantee that storing the update to
-    //  'reduce_memory()' will complete before storing the the update to
+    //  'reduce_memory()' will complete before storing the update to
     //  'm_pool_state'.
 
     memory_fence();
@@ -403,7 +390,7 @@ class ThreadsInternal {
   static void start(void (*)(ThreadsInternal &, const void *), const void *);
 
 #ifdef KOKKOS_ENABLE_DEPRECATED_CODE_4
-  KOKKOS_DEPRECATED static int in_parallel();
+  static int in_parallel();
 #endif
   static void fence();
   static void fence(const std::string &);
@@ -552,10 +539,6 @@ KOKKOS_DEPRECATED inline int Threads::in_parallel() {
 }
 #endif
 
-inline int Threads::impl_is_initialized() {
-  return Impl::ThreadsInternal::is_initialized();
-}
-
 inline void Threads::impl_initialize(InitializationSettings const &settings) {
   Impl::ThreadsInternal::initialize(
       settings.has_num_threads() ? settings.get_num_threads() : -1);
