@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #ifndef KOKKOS_DECLARE_THREADS_HPP
 #define KOKKOS_DECLARE_THREADS_HPP
@@ -30,6 +17,7 @@
 #include <Threads/Kokkos_Threads_ParallelScan_Range.hpp>
 #include <Threads/Kokkos_Threads_Team.hpp>
 #include <Threads/Kokkos_Threads_UniqueToken.hpp>
+#include <Threads/Kokkos_Threads_ZeroMemset.hpp>
 #endif
 
 #endif
