@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #ifndef KOKKOS_COMBINED_REDUCER_HPP
 #define KOKKOS_COMBINED_REDUCER_HPP
@@ -229,9 +216,9 @@ struct CombinedReducerImpl<std::integer_sequence<size_t, Idxs...>, Space,
   }
 
   template <class ExecutionSpace, int Idx, class View>
-  static void write_one_value_back(
-      const ExecutionSpace& exec_space, View const& view,
-      typename View::const_value_type& value) noexcept {
+  static void write_one_value_back(const ExecutionSpace& exec_space,
+                                   View const& view,
+                                   typename View::const_value_type& value) {
     if (Kokkos::SpaceAccessibility<typename View::memory_space,
                                    Space>::assignable)
       view() = value;
@@ -242,7 +229,7 @@ struct CombinedReducerImpl<std::integer_sequence<size_t, Idxs...>, Space,
   template <class ExecutionSpace>
   static void write_value_back_to_original_references(
       const ExecutionSpace& exec_space, value_type const& value,
-      Reducers const&... reducers_that_reference_original_values) noexcept {
+      Reducers const&... reducers_that_reference_original_values) {
     (write_one_value_back<ExecutionSpace, Idxs>(
          exec_space, reducers_that_reference_original_values.view(),
          value.template get<Idxs, typename Reducers::value_type>()),
@@ -363,13 +350,14 @@ struct CombinedReductionFunctorWrapperImpl<
   // TODO: forward final() function to user functor hook, or just ignore it?
 
  private:
+  // NOLINTBEGIN(cppcoreguidelines-rvalue-reference-param-not-moved)
   // variadic forwarding for MDRangePolicy
   // see comment above for why this has to be so gross
   // recursive case
   template <class... IdxOrMemberTypes, class IdxOrMemberType1,
             class... IdxOrMemberTypesThenValueType>
   KOKKOS_FORCEINLINE_FUNCTION std::enable_if_t<
-      !std::is_same_v<remove_cvref_t<IdxOrMemberType1>, value_type>>
+      !std::is_same_v<std::remove_cvref_t<IdxOrMemberType1>, value_type>>
   _call_op_impl(IdxOrMemberTypes&&... idxs, IdxOrMemberType1&& idx,
                 IdxOrMemberTypesThenValueType&&... args) const {
     this->template _call_op_impl<IdxOrMemberTypes&&..., IdxOrMemberType1&&>(
@@ -384,6 +372,7 @@ struct CombinedReductionFunctorWrapperImpl<
     m_functor((IdxOrMemberTypes&&)idxs...,
               out.template get<Idxs, typename Reducers::value_type>()...);
   }
+  // NOLINTEND(cppcoreguidelines-rvalue-reference-param-not-moved)
 };
 
 template <class Functor, class Space, class... Reducers>
@@ -534,8 +523,7 @@ template <class PolicyType, class Functor, class ReturnType1, class ReturnType2,
           class... ReturnTypes>
 auto parallel_reduce(std::string const& label, PolicyType const& policy,
                      Functor const& functor, ReturnType1&& returnType1,
-                     ReturnType2&& returnType2,
-                     ReturnTypes&&... returnTypes) noexcept
+                     ReturnType2&& returnType2, ReturnTypes&&... returnTypes)
     -> std::enable_if_t<Kokkos::is_execution_policy<PolicyType>::value> {
   //----------------------------------------
   // Since we don't support asynchronous combined reducers yet for various
@@ -585,7 +573,7 @@ template <class PolicyType, class Functor, class ReturnType1, class ReturnType2,
           class... ReturnTypes>
 auto parallel_reduce(PolicyType const& policy, Functor const& functor,
                      ReturnType1&& returnType1, ReturnType2&& returnType2,
-                     ReturnTypes&&... returnTypes) noexcept
+                     ReturnTypes&&... returnTypes)
     -> std::enable_if_t<Kokkos::is_execution_policy<PolicyType>::value> {
   //----------------------------------------
   Kokkos::parallel_reduce("", policy, functor,
@@ -599,7 +587,7 @@ template <class Functor, class ReturnType1, class ReturnType2,
           class... ReturnTypes>
 void parallel_reduce(std::string const& label, size_t n, Functor const& functor,
                      ReturnType1&& returnType1, ReturnType2&& returnType2,
-                     ReturnTypes&&... returnTypes) noexcept {
+                     ReturnTypes&&... returnTypes) {
   Kokkos::parallel_reduce(label,
                           RangePolicy<Kokkos::DefaultExecutionSpace>(0, n),
                           functor, std::forward<ReturnType1>(returnType1),
@@ -611,7 +599,7 @@ template <class Functor, class ReturnType1, class ReturnType2,
           class... ReturnTypes>
 void parallel_reduce(size_t n, Functor const& functor,
                      ReturnType1&& returnType1, ReturnType2&& returnType2,
-                     ReturnTypes&&... returnTypes) noexcept {
+                     ReturnTypes&&... returnTypes) {
   Kokkos::parallel_reduce("", n, functor,
                           std::forward<ReturnType1>(returnType1),
                           std::forward<ReturnType2>(returnType2),
