@@ -1,20 +1,13 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+#else
 #include <Kokkos_Core.hpp>
+#endif
+#include <Kokkos_TypeInfo.hpp>
 
 namespace {
 
@@ -377,7 +370,7 @@ struct PlusEqualAtomicViewFunctor {
 template <class T, class execution_space>
 T PlusEqualAtomicView(const int64_t input_length) {
   using view_type      = Kokkos::View<T*, execution_space>;
-  using host_view_type = typename view_type::HostMirror;
+  using host_view_type = typename view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -466,7 +459,7 @@ struct MinusEqualAtomicViewFunctor {
 template <class T, class execution_space>
 T MinusEqualAtomicView(const int64_t input_length) {
   using view_type      = Kokkos::View<T*, execution_space>;
-  using host_view_type = typename view_type::HostMirror;
+  using host_view_type = typename view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -550,7 +543,7 @@ struct TimesEqualAtomicViewFunctor {
 template <class T, class execution_space>
 T TimesEqualAtomicView(const int64_t input_length, const int64_t remainder) {
   using view_type      = Kokkos::View<T*, execution_space>;
-  using host_view_type = typename view_type::HostMirror;
+  using host_view_type = typename view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -634,7 +627,7 @@ template <class T, class execution_space>
 T DivEqualAtomicView(const int64_t input_length, const int64_t remainder) {
   using view_type             = Kokkos::View<T*, execution_space>;
   using scalar_view_type      = Kokkos::View<T, execution_space>;
-  using host_scalar_view_type = typename scalar_view_type::HostMirror;
+  using host_scalar_view_type = typename scalar_view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -716,7 +709,7 @@ template <class T, class execution_space>
 T ModEqualAtomicView(const int64_t input_length, const int64_t remainder) {
   using view_type             = Kokkos::View<T*, execution_space>;
   using scalar_view_type      = Kokkos::View<T, execution_space>;
-  using host_scalar_view_type = typename scalar_view_type::HostMirror;
+  using host_scalar_view_type = typename scalar_view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -812,7 +805,7 @@ T RSEqualAtomicView(const int64_t input_length, const int64_t value,
                     const int64_t remainder) {
   using view_type             = Kokkos::View<T*, execution_space>;
   using result_view_type      = Kokkos::View<T****, execution_space>;
-  using host_scalar_view_type = typename result_view_type::HostMirror;
+  using host_scalar_view_type = typename result_view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -932,7 +925,7 @@ T LSEqualAtomicView(const int64_t input_length, const int64_t value,
                     const int64_t remainder) {
   using view_type             = Kokkos::View<T*, execution_space>;
   using result_view_type      = Kokkos::View<T****, execution_space>;
-  using host_scalar_view_type = typename result_view_type::HostMirror;
+  using host_scalar_view_type = typename result_view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -1044,7 +1037,7 @@ struct AndEqualAtomicViewFunctor {
 template <class T, class execution_space>
 T AndEqualAtomicView(const int64_t input_length) {
   using view_type      = Kokkos::View<T*, execution_space>;
-  using host_view_type = typename view_type::HostMirror;
+  using host_view_type = typename view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -1125,7 +1118,7 @@ struct OrEqualAtomicViewFunctor {
 template <class T, class execution_space>
 T OrEqualAtomicView(const int64_t input_length) {
   using view_type      = Kokkos::View<T*, execution_space>;
-  using host_view_type = typename view_type::HostMirror;
+  using host_view_type = typename view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
@@ -1209,7 +1202,7 @@ struct XOrEqualAtomicViewFunctor {
 template <class T, class execution_space>
 T XOrEqualAtomicView(const int64_t input_length) {
   using view_type      = Kokkos::View<T*, execution_space>;
-  using host_view_type = typename view_type::HostMirror;
+  using host_view_type = typename view_type::host_mirror_type;
 
   const int64_t length = input_length;
 
