@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <Kokkos_BitManipulation.hpp>
 #include <cstdint>
@@ -405,7 +392,7 @@ constexpr auto test_bit_width(UInt x) -> decltype(Kokkos::bit_width(x)) {
   using Kokkos::bit_width;
 
   static_assert(noexcept(bit_width(x)));
-  static_assert(std::is_same_v<decltype(bit_width(x)), UInt>);
+  static_assert(std::is_same_v<decltype(bit_width(x)), int>);
 
   constexpr auto dig = Kokkos::Experimental::digits_v<UInt>;
   constexpr auto max = Kokkos::Experimental::finite_max_v<UInt>;
