@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <Kokkos_Macros.hpp>
 
@@ -31,7 +18,13 @@
 #endif
 #endif
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+#else
 #include <Kokkos_Core.hpp>
+#endif
+#include <complex>
 #include <sstream>
 
 namespace {
@@ -46,7 +39,7 @@ namespace Test {
 template <class ExecSpace>
 struct TestComplexConstruction {
   Kokkos::View<Kokkos::complex<double> *, ExecSpace> d_results;
-  typename Kokkos::View<Kokkos::complex<double> *, ExecSpace>::HostMirror
+  typename Kokkos::View<Kokkos::complex<double> *, ExecSpace>::host_mirror_type
       h_results;
 
   void testit() {
@@ -127,7 +120,7 @@ TEST(TEST_CATEGORY, complex_construction) {
 template <class ExecSpace>
 struct TestComplexBasicMath {
   Kokkos::View<Kokkos::complex<double> *, ExecSpace> d_results;
-  typename Kokkos::View<Kokkos::complex<double> *, ExecSpace>::HostMirror
+  typename Kokkos::View<Kokkos::complex<double> *, ExecSpace>::host_mirror_type
       h_results;
 
   void testit() {
@@ -279,7 +272,7 @@ TEST(TEST_CATEGORY, complex_basic_math) {
 template <class ExecSpace>
 struct TestComplexSpecialFunctions {
   Kokkos::View<Kokkos::complex<double> *, ExecSpace> d_results;
-  typename Kokkos::View<Kokkos::complex<double> *, ExecSpace>::HostMirror
+  typename Kokkos::View<Kokkos::complex<double> *, ExecSpace>::host_mirror_type
       h_results;
 
   void testit() {
@@ -342,8 +335,7 @@ struct TestComplexSpecialFunctions {
     ASSERT_FLOAT_EQ(h_results(13).real(), r.real());
     ASSERT_FLOAT_EQ(h_results(13).imag(), r.imag());
     // atanh
-    // Work around a bug in gcc 5.3.1 where the compiler cannot compute atanh
-    r = {0.163481616851666003, 1.27679502502111284};
+    r = std::atanh(a);
     ASSERT_FLOAT_EQ(h_results(14).real(), r.real());
     ASSERT_FLOAT_EQ(h_results(14).imag(), r.imag());
     r = std::asin(a);
@@ -353,8 +345,7 @@ struct TestComplexSpecialFunctions {
     ASSERT_FLOAT_EQ(h_results(16).real(), r.real());
     ASSERT_FLOAT_EQ(h_results(16).imag(), r.imag());
     // atan
-    // Work around a bug in gcc 5.3.1 where the compiler cannot compute atan
-    r = {1.380543138238714, 0.2925178131625636};
+    r = std::atan(a);
     ASSERT_FLOAT_EQ(h_results(17).real(), r.real());
     ASSERT_FLOAT_EQ(h_results(17).imag(), r.imag());
     // log10
@@ -414,15 +405,12 @@ TEST(TEST_CATEGORY, complex_special_funtions) {
 
 TEST(TEST_CATEGORY, complex_io) { testComplexIO(); }
 
-TEST(TEST_CATEGORY, complex_trivially_copyable) {
-  // Kokkos::complex<RealType> is trivially copyable when RealType is
-  // trivially copyable
-  using RealType = double;
-  // clang claims compatibility with gcc 4.2.1 but all versions tested know
-  // about std::is_trivially_copyable.
-  ASSERT_TRUE(std::is_trivially_copyable_v<Kokkos::complex<RealType>> ||
-              !std::is_trivially_copyable_v<RealType>);
-}
+static_assert(std::is_trivially_copyable_v<Kokkos::complex<float>>);
+static_assert(std::is_trivially_copyable_v<Kokkos::complex<double>>);
+#ifndef KOKKOS_IMPL_32BIT  // FIXME_32BIT
+// error: requested alignment '24' is not a positive power of 2
+static_assert(std::is_trivially_copyable_v<Kokkos::complex<long double>>);
+#endif
 
 template <class ExecSpace>
 struct TestBugPowAndLogComplex {
@@ -556,7 +544,7 @@ struct TestComplexStructuredBindings {
   using value_type       = double;
   using complex_type     = Kokkos::complex<double>;
   using device_view_type = Kokkos::View<complex_type *, exec_space>;
-  using host_view_type   = typename device_view_type::HostMirror;
+  using host_view_type   = typename device_view_type::host_mirror_type;
 
   device_view_type d_results;
   host_view_type h_results;
