@@ -1,20 +1,12 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+#else
 #include <Kokkos_Core.hpp>
+#endif
 #include <Kokkos_Graph.hpp>
 
 #include <gtest/gtest.h>
@@ -128,14 +120,14 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), submit_once) {
       });
   graph.submit();
 
-  ASSERT_TRUE(contains(graph.get_execution_space(), count, 1));
-  ASSERT_TRUE(contains(graph.get_execution_space(), bugs, 0));
+  ASSERT_TRUE(contains(TEST_EXECSPACE{}, count, 1));
+  ASSERT_TRUE(contains(TEST_EXECSPACE{}, bugs, 0));
 }
 
 TEST_F(TEST_CATEGORY_FIXTURE(graph), submit_once_rvalue) {
   Kokkos::Experimental::create_graph(ex, [&](auto root) {
     root.then_parallel_for(1, count_functor{count, bugs, 0, 0});
-  }).submit();
+  }).submit(ex);
 
   ASSERT_TRUE(contains(ex, count, 1));
   ASSERT_TRUE(contains(ex, bugs, 0));
@@ -149,7 +141,7 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), instantiate_and_submit_once) {
     root.then_parallel_for(1, count_functor{count, bugs, 0, 0});
   });
   graph.instantiate();
-  graph.submit();
+  graph.submit(ex);
 
   ASSERT_TRUE(contains(ex, count, 1));
   ASSERT_TRUE(contains(ex, bugs, 0));
@@ -203,11 +195,6 @@ TEST_F(TEST_CATEGORY_FIXTURE_DEATH(graph), can_instantiate_only_once) {
 // one passed to the Kokkos::Graph constructor.
 TEST_F(TEST_CATEGORY_FIXTURE(graph),
        submit_onto_another_execution_space_instance) {
-#ifdef KOKKOS_ENABLE_OPENMP  // FIXME_OPENMP partition_space
-  if (ex.concurrency() < 2)
-    GTEST_SKIP() << "insufficient number of supported concurrent threads";
-#endif
-
   const auto execution_space_instances =
       Kokkos::Experimental::partition_space(ex, 1, 1);
 
@@ -299,7 +286,7 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), submit_six) {
     ready.then_parallel_for(2, count_functor{count, bugs, 0, 6});
     //----------------------------------------
   });
-  graph.submit();
+  graph.submit(ex);
 
   ASSERT_TRUE(contains(ex, count, 6));
   ASSERT_TRUE(contains(ex, bugs, 0));
@@ -319,7 +306,7 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), when_all_cycle) {
     Kokkos::Experimental::when_all(f1, f4, f3)
         .then_parallel_reduce(6, set_result_functor{count}, reduction_out);
     //----------------------------------------
-  }).submit();
+  }).submit(ex);
 
   ASSERT_TRUE(contains(ex, bugs, 0));
   ASSERT_TRUE(contains(ex, count, 7));
@@ -363,7 +350,7 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), repeat_chain) {
     constexpr int repeats = 10;
 
     for (int i = 0; i < repeats; ++i) {
-      graph.submit();
+      graph.submit(ex);
       ex.fence();
       EXPECT_EQ(2, count_host());
       EXPECT_EQ(0, bugs_host());
@@ -392,18 +379,18 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), zero_work_reduce) {
 // These fences are only necessary because of the weirdness of how CUDA
 // UVM works on pre pascal cards.
 #if defined(KOKKOS_ENABLE_CUDA) && defined(KOKKOS_ENABLE_CUDA_UVM) && \
-    (defined(KOKKOS_ARCH_KEPLER) || defined(KOKKOS_ARCH_MAXWELL))
+    defined(KOKKOS_ARCH_MAXWELL)
   Kokkos::fence();
 #endif
-  graph.submit();
+  graph.submit(ex);
   Kokkos::deep_copy(ex, count, 1);
 // These fences are only necessary because of the weirdness of how CUDA
 // UVM works on pre pascal cards.
 #if defined(KOKKOS_ENABLE_CUDA) && defined(KOKKOS_ENABLE_CUDA_UVM) && \
-    (defined(KOKKOS_ARCH_KEPLER) || defined(KOKKOS_ARCH_MAXWELL))
+    defined(KOKKOS_ARCH_MAXWELL)
   if constexpr (std::is_same_v<TEST_EXECSPACE, Kokkos::Cuda>) Kokkos::fence();
 #endif
-  graph.submit();
+  graph.submit(ex);
 
   ASSERT_TRUE(contains(ex, count, 0));
 }
@@ -438,13 +425,12 @@ struct SizedFunctor {
 TEST_F(TEST_CATEGORY_FIXTURE(graph), force_global_launch) {
 #if defined(KOKKOS_ENABLE_CUDA)
   if constexpr (!std::is_same_v<TEST_EXECSPACE, Kokkos::Cuda>) {
-#elif defined(KOKKOS_ENABLE_HIP) && defined(KOKKOS_IMPL_HIP_NATIVE_GRAPH)
+#elif defined(KOKKOS_ENABLE_HIP)
   if constexpr (!std::is_same_v<TEST_EXECSPACE, Kokkos::HIP>) {
 #endif
     GTEST_SKIP() << "This execution space does not support global launch.";
 
-#if defined(KOKKOS_ENABLE_CUDA) || \
-    (defined(KOKKOS_ENABLE_HIP) && defined(KOKKOS_IMPL_HIP_NATIVE_GRAPH))
+#if defined(KOKKOS_ENABLE_CUDA) || defined(KOKKOS_ENABLE_HIP)
   }
 
   using value_t   = int;
@@ -561,10 +547,11 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), sized_functor_launch) {
 // Ensure that an empty graph on the default host execution space
 // can be submitted.
 TEST_F(TEST_CATEGORY_FIXTURE(graph), empty_graph_default_host_exec) {
-  Kokkos::Experimental::Graph graph{Kokkos::DefaultHostExecutionSpace{}};
+  const Kokkos::DefaultHostExecutionSpace exec{};
+  Kokkos::Experimental::Graph graph{exec};
   graph.instantiate();
-  graph.submit();
-  graph.get_execution_space().fence();
+  graph.submit(exec);
+  exec.fence();
 }
 
 template <typename DataViewType, typename BufferViewType>
@@ -653,11 +640,6 @@ FetchValuesAndContribute(ViewType, const size_t (&)[NumIndices],
 //  \ /         fence(exec_1)               enforce dependencies.
 //   D          D(exec_0)
 TEST_F(TEST_CATEGORY_FIXTURE(graph), diamond) {
-#ifdef KOKKOS_ENABLE_OPENMP  // FIXME_OPENMP partition_space
-  if (ex.concurrency() < 4)
-    GTEST_SKIP() << "test needs at least 4 OpenMP threads";
-#endif
-
   const auto execution_space_instances =
       Kokkos::Experimental::partition_space(ex, 1, 1, 1, 1);
 
@@ -730,11 +712,6 @@ TEST_F(TEST_CATEGORY_FIXTURE(graph), diamond) {
 //                  fence(exec_1)
 //    F             F(exec_0)
 TEST_F(TEST_CATEGORY_FIXTURE(graph), end_of_submit_control_flow) {
-#ifdef KOKKOS_ENABLE_OPENMP  // FIXME_OPENMP partition_space
-  if (ex.concurrency() < 4)
-    GTEST_SKIP() << "insufficient number of supported concurrent threads";
-#endif
-
   const auto execution_space_instances =
       Kokkos::Experimental::partition_space(ex, 1, 1, 1, 1);
 
@@ -816,10 +793,14 @@ template <typename ViewType>
 struct ThenFunctor {
   static_assert(ViewType::rank() == 0);
 
+  struct TimesTwo {};
+
   ViewType data;
   typename ViewType::value_type value;
 
   KOKKOS_FUNCTION void operator()() const { data() += value; }
+
+  KOKKOS_FUNCTION void operator()(const TimesTwo) const { data() += 2 * value; }
 };
 
 // Supported graph node types.
@@ -839,15 +820,8 @@ struct GraphNodeTypes {
                                          Kokkos::Experimental::TypeErasedTag>;
 
 #if defined(KOKKOS_ENABLE_CUDA)
-// TODO check range of problematic nvcc/11.4 and gcc/10.x combos
-#if (defined(KOKKOS_COMPILER_GNU) &&                                 \
-     (KOKKOS_COMPILER_GNU >= 1000 && KOKKOS_COMPILER_GNU < 1100)) && \
-    (defined(KOKKOS_COMPILER_NVCC) && (KOKKOS_COMPILER_NVCC == 1140))
-  static constexpr bool support_capture = false;
-#else
   static constexpr bool support_capture = std::is_same_v<Exec, Kokkos::Cuda>;
-#endif
-#elif defined(KOKKOS_ENABLE_HIP) && defined(KOKKOS_IMPL_HIP_NATIVE_GRAPH)
+#elif defined(KOKKOS_ENABLE_HIP)
     static constexpr bool support_capture = std::is_same_v<Exec, Kokkos::HIP>;
 #elif defined(KOKKOS_ENABLE_SYCL) && defined(KOKKOS_IMPL_SYCL_GRAPH_SUPPORT)
   static constexpr bool support_capture = std::is_same_v<Exec, Kokkos::SYCL>;
@@ -866,7 +840,8 @@ struct GraphNodeTypes {
 
   // Type of a then node.
   using then_t =
-      Kokkos::Impl::GraphNodeThenImpl<Exec, ThenFunctor<Kokkos::View<int>>>;
+      Kokkos::Impl::GraphNodeThenImpl<Exec, Kokkos::Experimental::ThenPolicy<>,
+                                      ThenFunctor<Kokkos::View<int>>>;
 
   // Type of a host node.
   using host_t =
@@ -964,8 +939,7 @@ __global__ void set_to(DstType* const dst, const SrcTypes* const... srcs) {
 
 template <typename Exec>
 struct ExternalCapture {
-#if defined(KOKKOS_ENABLE_CUDA) ||                                           \
-    (defined(KOKKOS_ENABLE_HIP) && defined(KOKKOS_IMPL_HIP_NATIVE_GRAPH)) || \
+#if defined(KOKKOS_ENABLE_CUDA) || defined(KOKKOS_ENABLE_HIP) || \
     (defined(KOKKOS_ENABLE_SYCL) && defined(KOKKOS_IMPL_SYCL_GRAPH_SUPPORT))
   // clang-format off
   template <typename Pred, typename DstType, typename... SrcTypes>
@@ -994,7 +968,7 @@ struct ExternalCapture {
         <<<dim3(1, 1, 1), dim3(1, 1, 1), 0, exec.cuda_stream()>>>(dst, srcs...);
   }
 #endif
-#if defined(KOKKOS_ENABLE_HIP) && defined(KOKKOS_IMPL_HIP_NATIVE_GRAPH)
+#if defined(KOKKOS_ENABLE_HIP)
   template <typename DstType, typename... SrcTypes>
   static void compute(const Kokkos::HIP& exec, DstType* const dst,
                       const SrcTypes* const... srcs) {
@@ -1125,7 +1099,8 @@ TEST(TEST_CATEGORY, graph_then) {
   using node_ref_memset_t =
       Kokkos::Experimental::GraphNodeRef<TEST_EXECSPACE, node_memset_t,
                                          typename types::node_ref_root_t>;
-  using node_then_t = Kokkos::Impl::GraphNodeThenImpl<TEST_EXECSPACE, then_t>;
+  using node_then_t = Kokkos::Impl::GraphNodeThenImpl<
+      TEST_EXECSPACE, Kokkos::Experimental::ThenPolicy<>, then_t>;
   using node_ref_then_t =
       Kokkos::Experimental::GraphNodeRef<TEST_EXECSPACE, node_then_t,
                                          node_ref_memset_t>;
@@ -1169,10 +1144,12 @@ struct ThenIncrementAndCombineFunctor
 };
 
 template <typename T>
-struct GraphIsDefaulted : std::true_type {};
+struct GraphIsDefaulted : std::false_type {};
 
-#if defined(KOKKOS_ENABLE_CUDA) ||                                           \
-    (defined(KOKKOS_ENABLE_HIP) && defined(KOKKOS_IMPL_HIP_NATIVE_GRAPH)) || \
+template <typename Exec>
+struct GraphIsDefaulted<Kokkos::Experimental::Graph<Exec>> : std::true_type {};
+
+#if defined(KOKKOS_ENABLE_CUDA) || defined(KOKKOS_ENABLE_HIP) || \
     (defined(KOKKOS_ENABLE_SYCL) && defined(KOKKOS_IMPL_SYCL_GRAPH_SUPPORT))
 template <>
 struct GraphIsDefaulted<
@@ -1181,7 +1158,8 @@ struct GraphIsDefaulted<
 #endif
 
 template <typename T>
-constexpr bool is_graph_defaulted = GraphIsDefaulted<T>::value;
+constexpr bool is_graph_defaulted =
+    GraphIsDefaulted<std::remove_cv_t<T>>::value;
 
 // A graph with only one node that is a then_host node.
 TEST(TEST_CATEGORY, then_host) {
@@ -1201,15 +1179,7 @@ TEST(TEST_CATEGORY, then_host) {
     });
     // clang-format on
 
-    // The SYCL host node moves the functor, but the functor's view is not
-    // properly moved. So we get one more reference count.
-#if defined(KOKKOS_ENABLE_SYCL) && defined(KOKKOS_IMPL_SYCL_GRAPH_SUPPORT) && \
-    defined(KOKKOS_ENABLE_IMPL_VIEW_LEGACY)
-    constexpr size_t expt_use_count =
-        1 + 1 + std::is_same_v<TEST_EXECSPACE, Kokkos::SYCL>;
-#else
-      constexpr size_t expt_use_count = 1 + 1;
-#endif
+    constexpr size_t expt_use_count = 1 + 1;
     ASSERT_EQ(counter.use_count(), expt_use_count);
 
     using namespace Kokkos::Test::Tools;
@@ -1271,15 +1241,7 @@ void test_mixed_host_device_nodes();
       });
       // clang-format on
 
-      // The SYCL host node moves the functor, but the functor's view is not
-      // properly moved. So we get one more reference count.
-#if defined(KOKKOS_ENABLE_SYCL) && defined(KOKKOS_IMPL_SYCL_GRAPH_SUPPORT) && \
-    defined(KOKKOS_ENABLE_IMPL_VIEW_LEGACY)
-      constexpr size_t expt_use_count =
-          1 + 3 + std::is_same_v<TEST_EXECSPACE, Kokkos::SYCL>;
-#else
       constexpr size_t expt_use_count = 1 + 3;
-#endif
       ASSERT_EQ(counter.use_count(), expt_use_count);
 
       graph.submit(exec);
@@ -1300,4 +1262,109 @@ TEST(TEST_CATEGORY, mixed_then_host_device_nodes) {
   }
 }
 
+// Ensure that in the default implementation, fencing occurs as needed
+// to ensure that dependencies are met when using an aggregate node.
+//
+// The graph is:
+//
+//              root
+//          (exec_default)
+//               *
+//            *      *
+//    node left      node right
+// (exec_default)  (exec_default)
+//            *      *
+//               *
+//            when_all
+//         (exec_default)
+//               *
+//               *
+//           node final
+//          (exec_other)
+//
+// The default implementation need not fence in the upper part of the graph
+// (diamond) because all nodes are on the same execution space instance.
+// However, before executing 'node final', we must ensure that 'node left' and
+// 'node right' have executed, and so the when_all must be waited for and a
+// fence is needed.
+TEST_F(TEST_CATEGORY_FIXTURE(graph), aggregate_is_awaitable) {
+  const TEST_EXECSPACE exec_default{};
+  const auto exec_instances =
+      Kokkos::Experimental::partition_space(exec_default, std::vector<int>{1});
+  const auto& exec_other = exec_instances.at(0);
+
+  using witness_t =
+      Kokkos::View<int, TEST_EXECSPACE, Kokkos::MemoryTraits<Kokkos::Atomic>>;
+  const witness_t witness(Kokkos::view_alloc("witness", exec_default));
+
+  const Kokkos::Experimental::Graph graph{exec_default};
+  const auto root = graph.root_node();
+  auto node_left =
+      root.then("node left", exec_default, ThenFunctor<witness_t>{witness, 1});
+  auto node_right =
+      root.then("node right", exec_default, ThenFunctor<witness_t>{witness, 1});
+  Kokkos::Experimental::when_all(std::move(node_left), std::move(node_right))
+      .then("node final", exec_other, ThenFunctor<witness_t>{witness, 1});
+
+  using namespace Kokkos::Test::Tools;
+  listen_tool_events(Config::DisableAll(), Config::EnableFences());
+
+  if constexpr (is_graph_defaulted<decltype(graph)>) {
+    const auto matcher = [&](BeginFenceEvent fence) {
+      if (fence.name ==
+          "Kokkos::DefaultGraphNode::execute_node: sync "
+          "with predecessors")
+        return MatchDiagnostic{true};
+      else
+        return MatchDiagnostic{false};
+    };
+    if (exec_default != exec_other) {
+      ASSERT_TRUE(
+          validate_existence([&] { graph.submit(exec_other); }, matcher));
+    } else {
+      ASSERT_TRUE(validate_absence([&] { graph.submit(exec_other); }, matcher));
+    }
+  } else {
+    ASSERT_TRUE(validate_absence(
+        [&] { graph.submit(exec_other); },
+        [&](BeginFenceEvent) { return MatchDiagnostic{true}; }));
+  }
+
+  listen_tool_events(Config::DisableAll());
+
+  exec_other.fence("wait for the graph to complete");
+  const auto witness_h =
+      Kokkos::create_mirror_view_and_copy(Kokkos::HostSpace{}, witness);
+  ASSERT_EQ(witness_h(), 3);
+}
+
+// Ensure that a then can be given a work tag.
+TEST(TEST_CATEGORY, graph_then_tag) {
+  using view_t    = Kokkos::View<int, TEST_EXECSPACE>;
+  using functor_t = ThenFunctor<view_t>;
+
+  constexpr int value_then = 456;
+
+  const TEST_EXECSPACE exec{};
+
+  const view_t data(Kokkos::view_alloc(exec, "data used in 'then'"));
+
+  auto graph = Kokkos::Experimental::create_graph(exec, [&](const auto& root) {
+    const auto notag = root.then("no tag", functor_t{data, value_then});
+    const auto tagged_labelled =
+        notag.then("tag and label",
+                   Kokkos::Experimental::ThenPolicy<functor_t::TimesTwo>{},
+                   functor_t{data, value_then});
+    const auto tagged = tagged_labelled.then(
+        Kokkos::Experimental::ThenPolicy<functor_t::TimesTwo>{},
+        functor_t{data, value_then});
+  });
+
+  ASSERT_TRUE(contains(exec, data, 0));
+
+  graph.submit(exec);
+
+  ASSERT_TRUE(contains(exec, data, 5 * value_then));
+}
+
 }  // end namespace Test
