@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <fstream>
 #include <gtest/gtest.h>
@@ -29,7 +16,7 @@ struct TestExponentialIntergral1Function {
   using HostViewType = Kokkos::View<double*, Kokkos::HostSpace>;
 
   ViewType d_x, d_expint;
-  typename ViewType::HostMirror h_x, h_expint;
+  typename ViewType::host_mirror_type h_x, h_expint;
   HostViewType h_ref;
 
   void testit() {
@@ -105,11 +92,11 @@ struct TestComplexErrorFunction {
   using DblHostViewType = Kokkos::View<double*, Kokkos::HostSpace>;
 
   ViewType d_z, d_erf, d_erfcx;
-  typename ViewType::HostMirror h_z, h_erf, h_erfcx;
+  typename ViewType::host_mirror_type h_z, h_erf, h_erfcx;
   HostViewType h_ref_erf, h_ref_erfcx;
 
   DblViewType d_x, d_erfcx_dbl;
-  typename DblViewType::HostMirror h_x, h_erfcx_dbl;
+  typename DblViewType::host_mirror_type h_x, h_erfcx_dbl;
   DblHostViewType h_ref_erfcx_dbl;
 
   void testit() {
@@ -453,11 +440,11 @@ struct TestComplexBesselJ0Y0Function {
       Kokkos::View<Kokkos::complex<double>*, Kokkos::HostSpace>;
 
   ViewType d_z, d_cbj0, d_cby0;
-  typename ViewType::HostMirror h_z, h_cbj0, h_cby0;
+  typename ViewType::host_mirror_type h_z, h_cbj0, h_cby0;
   HostViewType h_ref_cbj0, h_ref_cby0;
 
   ViewType d_z_large, d_cbj0_large, d_cby0_large;
-  typename ViewType::HostMirror h_z_large, h_cbj0_large, h_cby0_large;
+  typename ViewType::host_mirror_type h_z_large, h_cbj0_large, h_cby0_large;
   HostViewType h_ref_cbj0_large, h_ref_cby0_large;
 
   void testit() {
@@ -505,12 +492,7 @@ struct TestComplexBesselJ0Y0Function {
     Kokkos::deep_copy(d_z, h_z);
 
     // Call Bessel functions
-#if (HIP_VERSION_MAJOR == 5) && (HIP_VERSION_MINOR == 4)
-    using Property =
-        Kokkos::Experimental::WorkItemProperty::ImplForceGlobalLaunch_t;
-#else
     using Property = Kokkos::Experimental::WorkItemProperty::None_t;
-#endif
     Kokkos::parallel_for(Kokkos::RangePolicy<ExecSpace, Property>(0, N), *this);
     Kokkos::fence();
 
@@ -749,11 +731,11 @@ struct TestComplexBesselJ1Y1Function {
       Kokkos::View<Kokkos::complex<double>*, Kokkos::HostSpace>;
 
   ViewType d_z, d_cbj1, d_cby1;
-  typename ViewType::HostMirror h_z, h_cbj1, h_cby1;
+  typename ViewType::host_mirror_type h_z, h_cbj1, h_cby1;
   HostViewType h_ref_cbj1, h_ref_cby1;
 
   ViewType d_z_large, d_cbj1_large, d_cby1_large;
-  typename ViewType::HostMirror h_z_large, h_cbj1_large, h_cby1_large;
+  typename ViewType::host_mirror_type h_z_large, h_cbj1_large, h_cby1_large;
   HostViewType h_ref_cbj1_large, h_ref_cby1_large;
 
   void testit() {
@@ -801,12 +783,7 @@ struct TestComplexBesselJ1Y1Function {
     Kokkos::deep_copy(d_z, h_z);
 
     // Call Bessel functions
-#if (HIP_VERSION_MAJOR == 5) && (HIP_VERSION_MINOR == 4)
-    using Property =
-        Kokkos::Experimental::WorkItemProperty::ImplForceGlobalLaunch_t;
-#else
     using Property = Kokkos::Experimental::WorkItemProperty::None_t;
-#endif
     Kokkos::parallel_for(Kokkos::RangePolicy<ExecSpace, Property>(0, N), *this);
     Kokkos::fence();
 
@@ -1050,11 +1027,11 @@ struct TestComplexBesselI0K0Function {
       Kokkos::View<Kokkos::complex<double>*, Kokkos::HostSpace>;
 
   ViewType d_z, d_cbi0, d_cbk0;
-  typename ViewType::HostMirror h_z, h_cbi0, h_cbk0;
+  typename ViewType::host_mirror_type h_z, h_cbi0, h_cbk0;
   HostViewType h_ref_cbi0, h_ref_cbk0;
 
   ViewType d_z_large, d_cbi0_large, d_cbk0_large;
-  typename ViewType::HostMirror h_z_large, h_cbi0_large, h_cbk0_large;
+  typename ViewType::host_mirror_type h_z_large, h_cbi0_large, h_cbk0_large;
   HostViewType h_ref_cbi0_large, h_ref_cbk0_large;
 
   void testit() {
@@ -1101,12 +1078,7 @@ struct TestComplexBesselI0K0Function {
     Kokkos::deep_copy(d_z, h_z);
 
     // Call Bessel functions
-#if (HIP_VERSION_MAJOR == 5) && (HIP_VERSION_MINOR == 4)
-    using Property =
-        Kokkos::Experimental::WorkItemProperty::ImplForceGlobalLaunch_t;
-#else
     using Property = Kokkos::Experimental::WorkItemProperty::None_t;
-#endif
     Kokkos::parallel_for(Kokkos::RangePolicy<ExecSpace, Property>(0, N), *this);
     Kokkos::fence();
 
@@ -1204,11 +1176,6 @@ struct TestComplexBesselI0K0Function {
         Kokkos::complex<double>(1.413897840559108e-27, -1.851678917759592e+25);
     h_ref_cbk0(25) = Kokkos::complex<double>(9.5496636116079915979, 0.);
 
-    // FIXME_HIP Disable the test when using ROCm 5.5 and 5.6 due to a known
-    // compiler bug
-#if !defined(KOKKOS_ENABLE_HIP) || (HIP_VERSION_MAJOR != 5) || \
-    ((HIP_VERSION_MAJOR == 5) &&                               \
-     !((HIP_VERSION_MINOR == 5) || (HIP_VERSION_MINOR == 6)))
     for (int i = 0; i < N; i++) {
       EXPECT_LE(Kokkos::abs(h_cbi0(i) - h_ref_cbi0(i)),
                 Kokkos::abs(h_ref_cbi0(i)) * 1e-13);
@@ -1224,7 +1191,6 @@ struct TestComplexBesselI0K0Function {
                 Kokkos::abs(h_ref_cbk0(i)) * 1e-13)
           << "at index " << i;
     }
-#endif
 #endif
 
     ////Test large arguments
@@ -1306,11 +1272,11 @@ struct TestComplexBesselI1K1Function {
       Kokkos::View<Kokkos::complex<double>*, Kokkos::HostSpace>;
 
   ViewType d_z, d_cbi1, d_cbk1;
-  typename ViewType::HostMirror h_z, h_cbi1, h_cbk1;
+  typename ViewType::host_mirror_type h_z, h_cbi1, h_cbk1;
   HostViewType h_ref_cbi1, h_ref_cbk1;
 
   ViewType d_z_large, d_cbi1_large, d_cbk1_large;
-  typename ViewType::HostMirror h_z_large, h_cbi1_large, h_cbk1_large;
+  typename ViewType::host_mirror_type h_z_large, h_cbi1_large, h_cbk1_large;
   HostViewType h_ref_cbi1_large, h_ref_cbk1_large;
 
   void testit() {
@@ -1356,12 +1322,7 @@ struct TestComplexBesselI1K1Function {
     Kokkos::deep_copy(d_z, h_z);
 
     // Call Bessel functions
-#if (HIP_VERSION_MAJOR == 5) && (HIP_VERSION_MINOR == 4)
-    using Property =
-        Kokkos::Experimental::WorkItemProperty::ImplForceGlobalLaunch_t;
-#else
     using Property = Kokkos::Experimental::WorkItemProperty::None_t;
-#endif
     Kokkos::parallel_for(Kokkos::RangePolicy<ExecSpace, Property>(0, N), *this);
     Kokkos::fence();
 
@@ -1557,7 +1518,7 @@ struct TestComplexBesselH1Function {
       Kokkos::View<Kokkos::complex<double>*, Kokkos::HostSpace>;
 
   ViewType d_z, d_ch10, d_ch11;
-  typename ViewType::HostMirror h_z, h_ch10, h_ch11;
+  typename ViewType::host_mirror_type h_z, h_ch10, h_ch11;
   HostViewType h_ref_ch10, h_ref_ch11;
 
   void testit() {
@@ -1603,12 +1564,7 @@ struct TestComplexBesselH1Function {
     Kokkos::deep_copy(d_z, h_z);
 
     // Call Hankel functions
-#if (HIP_VERSION_MAJOR == 5) && (HIP_VERSION_MINOR == 4)
-    using Property =
-        Kokkos::Experimental::WorkItemProperty::ImplForceGlobalLaunch_t;
-#else
     using Property = Kokkos::Experimental::WorkItemProperty::None_t;
-#endif
     Kokkos::parallel_for(Kokkos::RangePolicy<ExecSpace, Property>(0, N), *this);
     Kokkos::fence();
 
@@ -1755,7 +1711,7 @@ struct TestComplexBesselH2Function {
       Kokkos::View<Kokkos::complex<double>*, Kokkos::HostSpace>;
 
   ViewType d_z, d_ch20, d_ch21;
-  typename ViewType::HostMirror h_z, h_ch20, h_ch21;
+  typename ViewType::host_mirror_type h_z, h_ch20, h_ch21;
   HostViewType h_ref_ch20, h_ref_ch21;
 
   void testit() {
@@ -1908,12 +1864,9 @@ struct TestComplexBesselH2Function {
     h_ref_ch21(24) =
         Kokkos::complex<double>(1.629136145471347e-01, +1.530182458039000e-02);
 
-    // FIXME_HIP Disable the test when using ROCm 5.5, 5.6, and 6.2 due to a
-    // known compiler bug
-#if !(defined(KOKKOS_ENABLE_HIP) ||                          \
-      ((HIP_VERSION_MAJOR == 5 && HIP_VERSION_MINOR == 5) || \
-       (HIP_VERSION_MAJOR == 5 && HIP_VERSION_MINOR == 6) || \
-       (HIP_VERSION_MAJOR == 6 && HIP_VERSION_MINOR == 2)))
+    // FIXME_HIP Disable the test when 6.2 due to a known compiler bug
+#if !(defined(KOKKOS_ENABLE_HIP) || \
+      (HIP_VERSION_MAJOR == 6 && HIP_VERSION_MINOR == 2))
     EXPECT_EQ(h_ref_ch20(0), h_ch20(0));
     // FIXME_SYCL Failing for Intel GPUs highly dependent on optimization flags
 #if !(defined(KOKKOS_ENABLE_SYCL) && defined(KOKKOS_ARCH_INTEL_GPU)) || \
@@ -1948,6 +1901,9 @@ struct TestComplexBesselH2Function {
 };
 
 TEST(TEST_CATEGORY, mathspecialfunc_expint1) {
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
+#endif
   TestExponentialIntergral1Function<TEST_EXECSPACE> test;
   test.testit();
 }
@@ -1956,55 +1912,67 @@ TEST(TEST_CATEGORY, mathspecialfunc_expint1) {
 // runtime with LLVM/13.
 #ifndef KOKKOS_ENABLE_OPENMPTARGET
 TEST(TEST_CATEGORY, mathspecialfunc_errorfunc) {
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
+#endif
   TestComplexErrorFunction<TEST_EXECSPACE> test;
   test.testit();
 }
 #endif
 
 TEST(TEST_CATEGORY, mathspecialfunc_cbesselj0y0) {
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
+#endif
   TestComplexBesselJ0Y0Function<TEST_EXECSPACE> test;
   test.testit();
 }
 
 TEST(TEST_CATEGORY, mathspecialfunc_cbesselj1y1) {
-#if defined(KOKKOS_ENABLE_HIP) &&                         \
-    (HIP_VERSION_MAJOR == 5 && HIP_VERSION_MINOR == 3) && \
-    defined(KOKKOS_ARCH_AMD_GFX908)
-  if (std::is_same_v<TEST_EXECSPACE, Kokkos::HIP>)
-    GTEST_SKIP()
-        << "skipping since test is known to fail on MI100 with ROCm 5.3";
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
 #endif
   TestComplexBesselJ1Y1Function<TEST_EXECSPACE> test;
   test.testit();
 }
 
 TEST(TEST_CATEGORY, mathspecialfunc_cbesseli0k0) {
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
+#endif
   TestComplexBesselI0K0Function<TEST_EXECSPACE> test;
   test.testit();
 }
 
 TEST(TEST_CATEGORY, mathspecialfunc_cbesseli1k1) {
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
+#endif
   TestComplexBesselI1K1Function<TEST_EXECSPACE> test;
   test.testit();
 }
 
 TEST(TEST_CATEGORY, mathspecialfunc_cbesselh1stkind) {
-  // Disable the test when using ROCm 5.5, 5.6, and 6.2 due to a
-  // known compiler bug. The test always fails on MI100.
-#if defined(KOKKOS_ENABLE_HIP) &&                            \
-    (((HIP_VERSION_MAJOR == 5 && HIP_VERSION_MINOR == 5) ||  \
-      (HIP_VERSION_MAJOR == 5 && HIP_VERSION_MINOR == 6) ||  \
-      (HIP_VERSION_MAJOR == 6 && HIP_VERSION_MINOR == 2)) || \
+  // Disable the test when using 6.2 due to a known compiler bug. The test
+  // always fails on MI100.
+#if defined(KOKKOS_ENABLE_HIP) &&                          \
+    ((HIP_VERSION_MAJOR == 6 && HIP_VERSION_MINOR == 2) || \
      defined(KOKKOS_ARCH_AMD_GFX908))
   if (std::is_same_v<TEST_EXECSPACE, Kokkos::HIP>)
     GTEST_SKIP() << "skipping since test is known to fail on MI100 and for "
                     "some versions of ROCm";
+#endif
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
 #endif
   TestComplexBesselH1Function<TEST_EXECSPACE> test;
   test.testit();
 }
 
 TEST(TEST_CATEGORY, mathspecialfunc_cbesselh2ndkind) {
+#if __FINITE_MATH_ONLY__
+  GTEST_SKIP() << "skipping when compiling with -ffinite-math-only";
+#endif
   TestComplexBesselH2Function<TEST_EXECSPACE> test;
   test.testit();
 }
