@@ -1,22 +1,14 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <gtest/gtest.h>
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+#else
 #include <Kokkos_Core.hpp>
+#endif
 #include <sstream>
 #include <iostream>
 
@@ -277,10 +269,13 @@ struct TestViewAllocationLargeRank {
 TEST(TEST_CATEGORY, view_allocation_large_rank) {
 #ifdef KOKKOS_ARCH_AMPERE87
   GTEST_SKIP() << "skipping for Jetson devices that have only 8GB memory";
+#endif
+#ifdef KOKKOS_IMPL_32BIT
+  GTEST_SKIP() << "skipping for 32-bit builds";
 #endif
   using ExecutionSpace = typename TEST_EXECSPACE::execution_space;
   using MemorySpace    = typename TEST_EXECSPACE::memory_space;
-  constexpr int dim    = 16;
+  constexpr int dim    = 15;
   using FunctorType    = TestViewAllocationLargeRank<MemorySpace>;
   typename FunctorType::ViewType v("v", dim, dim, dim, dim, dim, dim, dim, dim);
 
