@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 
 #include <gtest/gtest.h>
 
@@ -20,7 +7,12 @@
 #include <iostream>
 #include <time.h>
 
+#include <Kokkos_Macros.hpp>
+#ifdef KOKKOS_ENABLE_EXPERIMENTAL_CXX20_MODULES
+import kokkos.core;
+#else
 #include <Kokkos_Core.hpp>
+#endif
 
 namespace Test {
 
@@ -38,8 +30,8 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double*, Kokkos::LayoutStride, exec_space> src("LayoutStride",
                                                                 layout);
 
-    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::HostMirror h_src =
-        Kokkos::create_mirror_view(src);
+    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::host_mirror_type
+        h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -48,8 +40,8 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double*, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double*, Kokkos::LayoutLeft, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double*, Kokkos::LayoutLeft, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -72,8 +64,8 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double**, Kokkos::LayoutStride, exec_space> src("LayoutStride",
                                                                  layout);
 
-    Kokkos::View<double**, Kokkos::LayoutStride, exec_space>::HostMirror h_src =
-        Kokkos::create_mirror_view(src);
+    Kokkos::View<double**, Kokkos::LayoutStride, exec_space>::host_mirror_type
+        h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -82,8 +74,8 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double**, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double**, Kokkos::LayoutLeft, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double**, Kokkos::LayoutLeft, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -106,7 +98,7 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double***, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double***, Kokkos::LayoutStride, exec_space>::HostMirror
+    Kokkos::View<double***, Kokkos::LayoutStride, exec_space>::host_mirror_type
         h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
@@ -116,8 +108,8 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double***, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double***, Kokkos::LayoutLeft, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double***, Kokkos::LayoutLeft, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -140,7 +132,7 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double****, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double****, Kokkos::LayoutStride, exec_space>::HostMirror
+    Kokkos::View<double****, Kokkos::LayoutStride, exec_space>::host_mirror_type
         h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
@@ -150,8 +142,8 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double****, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double****, Kokkos::LayoutLeft, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double****, Kokkos::LayoutLeft, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -174,8 +166,9 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double*****, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double*****, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double*****, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -184,7 +177,7 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double*****, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double*****, Kokkos::LayoutLeft, exec_space>::HostMirror
+    Kokkos::View<double*****, Kokkos::LayoutLeft, exec_space>::host_mirror_type
         h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
@@ -208,8 +201,9 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double******, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double******, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double******, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -218,7 +212,7 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double******, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double******, Kokkos::LayoutLeft, exec_space>::HostMirror
+    Kokkos::View<double******, Kokkos::LayoutLeft, exec_space>::host_mirror_type
         h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
@@ -242,8 +236,9 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double*******, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double*******, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double*******, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -252,8 +247,9 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double*******, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double*******, Kokkos::LayoutLeft, exec_space>::HostMirror
-        h_dst = Kokkos::create_mirror_view(dst);
+    Kokkos::View<double*******, Kokkos::LayoutLeft,
+                 exec_space>::host_mirror_type h_dst =
+        Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -276,8 +272,9 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
     Kokkos::View<double********, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double********, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double********, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -286,8 +283,9 @@ TEST(TEST_CATEGORY, view_layoutstride_left_to_layoutleft_assignment) {
 
     Kokkos::View<double********, Kokkos::LayoutLeft, exec_space> dst = src;
 
-    Kokkos::View<double********, Kokkos::LayoutLeft, exec_space>::HostMirror
-        h_dst = Kokkos::create_mirror_view(dst);
+    Kokkos::View<double********, Kokkos::LayoutLeft,
+                 exec_space>::host_mirror_type h_dst =
+        Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -317,8 +315,8 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double*, Kokkos::LayoutStride, exec_space> src("LayoutStride",
                                                                 layout);
 
-    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::HostMirror h_src =
-        Kokkos::create_mirror_view(src);
+    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::host_mirror_type
+        h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -327,8 +325,8 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double*, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double*, Kokkos::LayoutRight, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double*, Kokkos::LayoutRight, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -351,8 +349,8 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double**, Kokkos::LayoutStride, exec_space> src("LayoutStride",
                                                                  layout);
 
-    Kokkos::View<double**, Kokkos::LayoutStride, exec_space>::HostMirror h_src =
-        Kokkos::create_mirror_view(src);
+    Kokkos::View<double**, Kokkos::LayoutStride, exec_space>::host_mirror_type
+        h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -361,8 +359,8 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double**, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double**, Kokkos::LayoutRight, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double**, Kokkos::LayoutRight, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -385,7 +383,7 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double***, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double***, Kokkos::LayoutStride, exec_space>::HostMirror
+    Kokkos::View<double***, Kokkos::LayoutStride, exec_space>::host_mirror_type
         h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
@@ -395,8 +393,8 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double***, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double***, Kokkos::LayoutRight, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double***, Kokkos::LayoutRight, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -419,7 +417,7 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double****, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double****, Kokkos::LayoutStride, exec_space>::HostMirror
+    Kokkos::View<double****, Kokkos::LayoutStride, exec_space>::host_mirror_type
         h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
@@ -429,7 +427,7 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double****, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double****, Kokkos::LayoutRight, exec_space>::HostMirror
+    Kokkos::View<double****, Kokkos::LayoutRight, exec_space>::host_mirror_type
         h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
@@ -453,8 +451,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double*****, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double*****, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double*****, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -463,7 +462,7 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double*****, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double*****, Kokkos::LayoutRight, exec_space>::HostMirror
+    Kokkos::View<double*****, Kokkos::LayoutRight, exec_space>::host_mirror_type
         h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
@@ -487,8 +486,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double******, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double******, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double******, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -497,8 +497,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double******, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double******, Kokkos::LayoutRight, exec_space>::HostMirror
-        h_dst = Kokkos::create_mirror_view(dst);
+    Kokkos::View<double******, Kokkos::LayoutRight,
+                 exec_space>::host_mirror_type h_dst =
+        Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -521,8 +522,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double*******, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double*******, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double*******, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -531,8 +533,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double*******, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double*******, Kokkos::LayoutRight, exec_space>::HostMirror
-        h_dst = Kokkos::create_mirror_view(dst);
+    Kokkos::View<double*******, Kokkos::LayoutRight,
+                 exec_space>::host_mirror_type h_dst =
+        Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -555,8 +558,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
     Kokkos::View<double********, Kokkos::LayoutStride, exec_space> src(
         "LayoutStride", layout);
 
-    Kokkos::View<double********, Kokkos::LayoutStride, exec_space>::HostMirror
-        h_src = Kokkos::create_mirror_view(src);
+    Kokkos::View<double********, Kokkos::LayoutStride,
+                 exec_space>::host_mirror_type h_src =
+        Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -565,8 +569,9 @@ TEST(TEST_CATEGORY, view_layoutstride_right_to_layoutright_assignment) {
 
     Kokkos::View<double********, Kokkos::LayoutRight, exec_space> dst = src;
 
-    Kokkos::View<double********, Kokkos::LayoutRight, exec_space>::HostMirror
-        h_dst = Kokkos::create_mirror_view(dst);
+    Kokkos::View<double********, Kokkos::LayoutRight,
+                 exec_space>::host_mirror_type h_dst =
+        Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -596,8 +601,8 @@ TEST(TEST_CATEGORY_DEATH, view_layoutstride_right_to_layoutleft_assignment) {
     Kokkos::View<double*, Kokkos::LayoutStride, exec_space> src("LayoutStride",
                                                                 layout);
 
-    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::HostMirror h_src =
-        Kokkos::create_mirror_view(src);
+    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::host_mirror_type
+        h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -608,8 +613,8 @@ TEST(TEST_CATEGORY_DEATH, view_layoutstride_right_to_layoutleft_assignment) {
 
     dst = src;
 
-    Kokkos::View<double*, Kokkos::LayoutLeft, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double*, Kokkos::LayoutLeft, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
@@ -748,8 +753,8 @@ TEST(TEST_CATEGORY_DEATH, view_layoutstride_left_to_layoutright_assignment) {
     Kokkos::View<double*, Kokkos::LayoutStride, exec_space> src("LayoutStride",
                                                                 layout);
 
-    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::HostMirror h_src =
-        Kokkos::create_mirror_view(src);
+    Kokkos::View<double*, Kokkos::LayoutStride, exec_space>::host_mirror_type
+        h_src = Kokkos::create_mirror_view(src);
 
     for (size_t i = 0; i < src.span(); i++)
       h_src.data()[i] = (double)rand() / RAND_MAX * (100);
@@ -760,8 +765,8 @@ TEST(TEST_CATEGORY_DEATH, view_layoutstride_left_to_layoutright_assignment) {
 
     dst = src;
 
-    Kokkos::View<double*, Kokkos::LayoutRight, exec_space>::HostMirror h_dst =
-        Kokkos::create_mirror_view(dst);
+    Kokkos::View<double*, Kokkos::LayoutRight, exec_space>::host_mirror_type
+        h_dst = Kokkos::create_mirror_view(dst);
 
     Kokkos::deep_copy(h_dst, dst);
 
