@@ -1,18 +1,5 @@
-//@HEADER
-// ************************************************************************
-//
-//                        Kokkos v. 4.0
-//       Copyright (2022) National Technology & Engineering
-//               Solutions of Sandia, LLC (NTESS).
-//
-// Under the terms of Contract DE-NA0003525 with NTESS,
-// the U.S. Government retains certain rights in this software.
-//
-// Part of Kokkos, under the Apache License v2.0 with LLVM Exceptions.
-// See https://kokkos.org/LICENSE for license information.
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-//
-//@HEADER
+// SPDX-FileCopyrightText: Copyright Contributors to the Kokkos project
 #include <iostream>
 #include <gtest/gtest.h>
 #include "Kokkos_Core.hpp"
@@ -28,8 +15,8 @@ class OpenMP;
 class Cuda;
 class Threads;
 class HIP;
-namespace Experimental {
 class SYCL;
+namespace Experimental {
 class OpenMPTarget;
 class HPX;
 }  // namespace Experimental
@@ -107,7 +94,7 @@ struct TestScanFunctor {
 
 template <typename Lambda>
 void test_wrapper(const Lambda& lambda) {
-  if (!std::is_same<Kokkos::DefaultExecutionSpace, Kokkos::Serial>::value) {
+  if (!std::is_same_v<Kokkos::DefaultExecutionSpace, Kokkos::Serial>) {
     lambda();
   }
 }
@@ -197,7 +184,7 @@ TEST(kokkosp, test_multiple_default_instances) {
       ex1.fence("named_instance_fence_one");
       ex2.fence("named_instance_fence_two");
     });
-    ASSERT_TRUE(found_payloads[0].dev_id == found_payloads[1].dev_id);
+    ASSERT_EQ(found_payloads[0].dev_id, found_payloads[1].dev_id);
   });
 }
 
@@ -282,8 +269,8 @@ TEST(kokkosp, test_streams) {
 TEST(kokkosp, async_deep_copy) {
 // FIXME_OPENMPTARGET
 #ifdef KOKKOS_ENABLE_OPENMPTARGET
-  if (std::is_same<Kokkos::DefaultExecutionSpace,
-                   Kokkos::Experimental::OpenMPTarget>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace,
+                     Kokkos::Experimental::OpenMPTarget>)
     GTEST_SKIP()
         << "skipping since the OpenMPTarget backend has unexpected fences";
 #endif
@@ -363,8 +350,8 @@ TEST(kokkosp, parallel_reduce) {
 TEST(kokkosp, parallel_scan) {
   // FIXME_OPENMPTARGET
 #ifdef KOKKOS_ENABLE_OPENMPTARGET
-  if (std::is_same<Kokkos::DefaultExecutionSpace,
-                   Kokkos::Experimental::OpenMPTarget>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace,
+                     Kokkos::Experimental::OpenMPTarget>)
     GTEST_SKIP()
         << "skipping since the OpenMPTarget backend reports unexpected events";
 #endif
@@ -391,25 +378,36 @@ TEST(kokkosp, parallel_scan) {
 TEST(kokkosp, parallel_scan_no_fence) {
   // FIXME_THREADS
 #ifdef KOKKOS_ENABLE_THREADS
-  if (std::is_same<Kokkos::DefaultExecutionSpace, Kokkos::Threads>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace, Kokkos::Threads>)
     GTEST_SKIP() << "skipping since the Thread backend always fences";
+#endif
+#if defined(KOKKOS_ENABLE_HPX) && \
+    !defined(KOKKOS_ENABLE_IMPL_HPX_ASYNC_DISPATCH)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace, Kokkos::Experimental::HPX>)
+    GTEST_SKIP() << "skipping since the HPX backend always fences with async "
+                    "dispatch disabled";
 #endif
     // FIXME_OPENMPTARGET
 #ifdef KOKKOS_ENABLE_OPENMPTARGET
-  if (std::is_same<Kokkos::DefaultExecutionSpace,
-                   Kokkos::Experimental::OpenMPTarget>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace,
+                     Kokkos::Experimental::OpenMPTarget>)
     GTEST_SKIP()
         << "skipping since the OpenMPTarget backend has unexpected fences";
 #endif
 
+  // Execute the parallel_scan first without looking for fence events.
+  // Depending on the backend implementation and the order of tests,
+  // it might be that the first call to parallel_scan is reallocating scratch
+  // memory which implies a fence when deallocating. We are not interested in
+  // detecting this event.
+  TestScanFunctor tf;
+  Kokkos::parallel_scan("dogs", Kokkos::RangePolicy<>(0, 1), tf);
+
   using namespace Kokkos::Test::Tools;
   listen_tool_events(Config::DisableAll(), Config::EnableKernels(),
                      Config::EnableFences());
   auto success = validate_absence(
-      [=]() {
-        TestScanFunctor tf;
-        Kokkos::parallel_scan("dogs", Kokkos::RangePolicy<>(0, 1), tf);
-      },
+      [=]() { Kokkos::parallel_scan("dogs", Kokkos::RangePolicy<>(0, 1), tf); },
       [=](BeginFenceEvent begin_event) {
         if (begin_event.name.find("Debug Only Check for Execution Error") !=
                 std::string::npos ||
@@ -425,24 +423,37 @@ TEST(kokkosp, parallel_scan_no_fence) {
 TEST(kokkosp, parallel_scan_no_fence_view) {
   // FIXME_THREADS
 #ifdef KOKKOS_ENABLE_THREADS
-  if (std::is_same<Kokkos::DefaultExecutionSpace, Kokkos::Threads>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace, Kokkos::Threads>)
     GTEST_SKIP() << "skipping since the Thread backend always fences";
+#endif
+#if defined(KOKKOS_ENABLE_HPX) && \
+    !defined(KOKKOS_ENABLE_IMPL_HPX_ASYNC_DISPATCH)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace, Kokkos::Experimental::HPX>)
+    GTEST_SKIP() << "skipping since the HPX backend always fences with async "
+                    "dispatch disabled";
 #endif
     // FIXME_OPENMPTARGET
 #ifdef KOKKOS_ENABLE_OPENMPTARGET
-  if (std::is_same<Kokkos::DefaultExecutionSpace,
-                   Kokkos::Experimental::OpenMPTarget>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace,
+                     Kokkos::Experimental::OpenMPTarget>)
     GTEST_SKIP()
         << "skipping since the OpenMPTarget backend has unexpected fences";
 #endif
 
+  // Execute the parallel_scan first without looking for fence events.
+  // Depending on the backend implementation and the order of tests,
+  // it might be that the first call to parallel_scan is reallocating scratch
+  // memory which implies a fence when deallocating. We are not interested in
+  // detecting this event.
+  TestScanFunctor tf;
+  Kokkos::View<typename TestScanFunctor::value_type> v("scan_result");
+  Kokkos::parallel_scan("dogs", Kokkos::RangePolicy<>(0, 1), tf, v);
+
   using namespace Kokkos::Test::Tools;
   listen_tool_events(Config::DisableAll(), Config::EnableKernels(),
                      Config::EnableFences());
-  Kokkos::View<typename TestScanFunctor::value_type> v("scan_result");
   auto success = validate_absence(
       [=]() {
-        TestScanFunctor tf;
         Kokkos::parallel_scan("dogs", Kokkos::RangePolicy<>(0, 1), tf, v);
       },
       [=](BeginFenceEvent begin_event) {
@@ -496,8 +507,8 @@ TEST(kokkosp, fences) {
 TEST(kokkosp, raw_allocation) {
   // FIXME_OPENMPTARGET
 #ifdef KOKKOS_ENABLE_OPENMPTARGET
-  if (std::is_same<Kokkos::DefaultExecutionSpace,
-                   Kokkos::Experimental::OpenMPTarget>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace,
+                     Kokkos::Experimental::OpenMPTarget>)
     GTEST_SKIP()
         << "skipping since the OpenMPTarget backend reports unexpected events";
 #endif
@@ -535,8 +546,8 @@ TEST(kokkosp, raw_allocation) {
 TEST(kokkosp, view) {
 // FIXME_OPENMPTARGET
 #ifdef KOKKOS_ENABLE_OPENMPTARGET
-  if (std::is_same<Kokkos::DefaultExecutionSpace,
-                   Kokkos::Experimental::OpenMPTarget>::value)
+  if (std::is_same_v<Kokkos::DefaultExecutionSpace,
+                     Kokkos::Experimental::OpenMPTarget>)
     GTEST_SKIP()
         << "skipping since the OpenMPTarget backend reports unexpected events";
 #endif
@@ -715,8 +726,7 @@ TEST(kokkosp, get_events) {
     Kokkos::Tools::popRegion();
   });
   for (const auto& ptr : event_vector) {
-    auto ptr_as_begin = std::dynamic_pointer_cast<BeginParallelForEvent>(ptr);
-    ASSERT_TRUE(ptr_as_begin == nullptr);
+    ASSERT_FALSE(is_a<BeginParallelForEvent>(ptr));
   }
 }
 }  // namespace Test
